'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _popup = require('../mixins/popup');

require('./index.less');

var Popup = {
    mixins: [_popup.PopupMixin],
    data: function data() {
        return {
            inited: this.value
        };
    },

    props: {
        value: Boolean,
        overlay: {
            type: Boolean,
            'default': true
        },
        position: {
            type: String,
            'default': 'bottom'
        },
        overlayStyle: Object,
        duration: [Number, String]
    },
    beforeCreate: function beforeCreate() {
        var _this = this;

        var createEmitter = function createEmitter(eventName) {
            return function (event) {
                return _this.$emit(eventName, event);
            };
        };

        this.onClick = createEmitter('click');
        this.onOpened = createEmitter('opened');
        this.onClosed = createEmitter('closed');
    },

    methods: {},
    render: function render() {
        var h = arguments[0];

        if (!this.shouldRender) {
            return;
        }
        var value = this.value,
            position = this.position,
            duration = this.duration,
            $slots = this.$slots;

        var transitionName = 'sn-popup-slide-' + position;
        var style = {};
        if (duration !== undefined && duration !== null) {
            style.animationDuration = duration + 'ms';
        }
        var className = {
            'sn-popup': true
        };
        className['sn-popup-' + position] = true;

        return h(
            'transition',
            {
                attrs: { name: transitionName }
            },
            [h(
                'div',
                {
                    directives: [{
                        name: 'show',
                        value: value
                    }],

                    style: style,
                    'class': className,
                    on: {
                        'click': this.onClick
                    }
                },
                [$slots['default']]
            )]
        );
    }
};

exports['default'] = Popup;
module.exports = exports.default;